@@ -23,7 +23,7 @@ def connect(apikey=None, endpoint=None, **kwargs):
     endpoint : str, optional
         Treasure Data API server. If not given, ``https://api.treasuredata.com`` is
         used by default. List of available endpoints is:
-        https://tddocs.atlassian.net/wiki/spaces/PD/pages/1085143/Sites+and+Endpoints
+        https://docs.treasuredata.com/display/public/PD/Sites+and+Endpoints
 
     kwargs : dict, optional
         Optional arguments
@@ -173,8 +173,8 @@ def read_td_query(
         - ``wait_interval`` (int): sleep interval until job finish
         - ``wait_callback`` (function): called every interval against job itself
         - ``engine_version`` (str): run query with Hive 2 if this parameter is
-          set to ``"experimental"`` in ``HiveQueryEngine``.
-          https://tddocs.atlassian.net/wiki/spaces/PD/pages/1083123/Using+Hive+2+to+Create+Queries
+          set to ``"stable"`` in ``HiveQueryEngine``.
+          https://docs.treasuredata.com/display/public/PD/Writing+Hive+Queries
 
     Returns
     -------
@@ -484,7 +484,7 @@ def _convert_time_column(frame, time_col=None, time_index=None):
             col = pd.to_datetime(col)
         # convert pandas datetime to unixtime
         if col.dtype.name == "datetime64[ns]":
-            frame["time"] = col.astype("int64") // (10 ** 9)
+            frame["time"] = col.astype("int64") // (10**9)
     elif time_index is not None:
         # Use 'time_index' as time column
         if type(time_index) is bool or not isinstance(time_index, int):
@@ -499,7 +499,7 @@ def _convert_time_column(frame, time_col=None, time_index=None):
         if idx.dtype.name != "datetime64[ns]":
             raise TypeError("index type must be datetime64[ns]")
         # convert pandas datetime to unixtime
-        frame["time"] = idx.astype("int64") // (10 ** 9)
+        frame["time"] = idx.astype("int64") // (10**9)
     else:
         # Use current time as time column
         frame["time"] = int(time.time())
